/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'docprops', 'de', {
	bgColor: 'Hintergrundfarbe',
	bgFixed: 'Nichtrollender (feststehender) Hintergrund',
	bgImage: 'Hintergrundbild-URL',
	charset: 'Zeichensatzkodierung',
	charsetASCII: 'ASCII',
	charsetCE: 'Zentraleuropäisch',
	charsetCR: 'Kyrillisch',
	charsetCT: 'Traditionelles Chinesisch (Big5)',
	charsetGR: 'Griechisch',
	charsetJP: 'Japanisch',
	charsetKR: 'Koreanisch',
	charsetOther: 'Andere Zeichensatzkodierung',
	charsetTR: 'Türkisch',
	charsetUN: 'Unicode (UTF-8)',
	charsetWE: 'Westeuropäisch',
	chooseColor: 'Auswählen',
	design: 'Design',
	docTitle: 'Seitentitel',
	docType: 'Dokumententypüberschrift',
	docTypeOther: 'Andere Dokumententypüberschrift',
	label: 'Dokumenteigenschaften',
	margin: 'Seitenränder',
	marginBottom: 'Unten',
	marginLeft: 'Links',
	marginRight: 'Rechts',
	marginTop: 'Oben',
	meta: 'Metadaten',
	metaAuthor: 'Autor',
	metaCopyright: 'Copyright',
	metaDescription: 'Dokumentbeschreibung',
	metaKeywords: 'Schlüsselwörter (durch Komma getrennt)',
	other: 'Andere...',
	previewHtml: '<p>Das ist ein <strong>Beispieltext</strong>. Du schreibst in <a href="javascript:void(0)">CKEditor</a>.</p>',
	title: 'Dokumenteigenschaften',
	txtColor: 'Textfarbe',
	xhtmlDec: 'Beziehe XHTML Deklarationen ein'
} );
